@@ -39,7 +39,7 @@ C
 c       write(*,*) IC,NPEAK,IJ
 C
 	ADJUST=.FALSE.
-	CALL GGMLTRSTN(SY,RES,KNV,N,W,THRSH,KK,MULT,ADJUST,IJ)
+	CALL GGMLTRSTN(RES,KNV,N,W,THRSH,KK,MULT,ADJUST,IJ)
 	IC=IC+1
 C     
 	IF (ADJUST) THEN
@@ -274,7 +274,7 @@ C
       SUBROUTINE STRING0(L,U,N,STR1,KNX,KNV,FIXSTR)
       DOUBLE PRECISION L(N),U(N)
       INTEGER KNX(N),KNV(N)
-      DOUBLE PRECISION STR1
+      DOUBLE PRECISION GRX1,GRV0,STR1
       LOGICAL FIXSTR
 C
       FIXSTR=.FALSE.
@@ -384,8 +384,8 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C
 C
-      SUBROUTINE GGMLTRSTN(SY,RES,KNV,N,W,THRSH,KK,MULT,ADJUST,KIJ)
-      DOUBLE PRECISION SY(N+1),RES(N),W(N+1),THRSH(2*KK+2)
+      SUBROUTINE GGMLTRSTN(RES,KNV,N,W,THRSH,KK,MULT,ADJUST,KIJ)
+      DOUBLE PRECISION RES(N),W(N+1),THRSH(2*KK+2)
       INTEGER KNV(N)
       INTEGER MULT
       LOGICAL ADJUST
@@ -563,8 +563,8 @@ C
       DOUBLE PRECISION FUNCTION PRGAMMA(X,AK)
       DOUBLE PRECISION X,AK
 C
-      DOUBLE PRECISION A,AAK,DF,Y
-      DOUBLE PRECISION GAMMA,KH0,PRGAU
+      DOUBLE PRECISION A,AAK,Y
+      DOUBLE PRECISION FTGAMMA,KH0,PRGAU,SUM
 C
       IF(AK.GE.3D1.OR.DABS(X-AK).GE.2D0*DSQRT(AK)) THEN
          Y=X/AK
@@ -584,7 +584,7 @@ c         write(*,*) J
             A=A*X/(AK+DBLE(I))
             SUM=SUM+A
  20      CONTINUE
-         SUM=SUM*DEXP(AK*DLOG(X)-X)/GAMMA(AK+1D0)
+         SUM=SUM*DEXP(AK*DLOG(X)-X)/FTGAMMA(AK+1D0)
          Y=X/AAK
          PRGAMMA=SUM+PRGAU(DSQRT(2D0)*KH0(Y,AAK))
       ENDIF
@@ -604,7 +604,7 @@ C
          KH0=(X-1D0)**2/(X-1D0-DLOG(X))
          KH0=0.5D0*DLOG(KH0/2D0)
       ELSE
-         KH0=0D0
+         KH0=0.0D0
       ENDIF
 C
       KH0=KH0+AK*(X-1D0-DLOG(X))
@@ -670,8 +670,6 @@ C
       IF(DABS(XMIN-1D0).GT.1D-8) THEN
          Y=(XMIN-1D0)**2/(XMIN-1D0-DLOG(XMIN))
          Y=0.5D0*DLOG(Y/2D0)
-      ELSE
-         KH0=0D0
       ENDIF
 C
       Y=Y+AK*(XMIN-1D0-DLOG(XMIN))
@@ -725,7 +723,7 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C
 C
-      DOUBLE PRECISION FUNCTION GAMMA(K)
+      DOUBLE PRECISION FUNCTION FTGAMMA(K)
       DOUBLE PRECISION K
 C
       DOUBLE PRECISION A,R2PI
@@ -735,32 +733,32 @@ C
 C
       IF(K.GE.5D0) THEN
          A=K-1D0
-         GAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
+         FTGAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
      +        -1D0/(360D0*A**3))
       ELSEIF(K.GE.4D0) THEN
-         GAMMA=R2PI*DSQRT(K)*DEXP(K*DLOG(K)-K+1D0/(12D0*K)
+         FTGAMMA=R2PI*DSQRT(K)*DEXP(K*DLOG(K)-K+1D0/(12D0*K)
      +        -1D0/(360D0*K**3))
-         GAMMA=GAMMA/K
+         FTGAMMA=FTGAMMA/K
       ELSEIF(K.GE.3D0) THEN
          A=K+1D0
-         GAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
+         FTGAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
      +        -1D0/(360D0*A**3))
-         GAMMA=GAMMA/(K*(K+1D0))
+         FTGAMMA=FTGAMMA/(K*(K+1D0))
       ELSEIF(K.GE.2D0) THEN
          A=K+2D0
-         GAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
+         FTGAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
      +        -1D0/(360D0*A**3))
-         GAMMA=GAMMA/(K*(K+1D0)*(K+2D0))
+         FTGAMMA=FTGAMMA/(K*(K+1D0)*(K+2D0))
       ELSEIF(K.GE.1D0) THEN
          A=K+3D0
-         GAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
+         FTGAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
      +        -1D0/(360D0*A**3))
-         GAMMA=GAMMA/(K*(K+1D0)*(K+2D0)*(K+3D0))
+         FTGAMMA=FTGAMMA/(K*(K+1D0)*(K+2D0)*(K+3D0))
       ELSE
          A=K+4D0
-         GAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
+         FTGAMMA=R2PI*DSQRT(A)*DEXP(A*DLOG(A)-A+1D0/(12D0*A)
      +        -1D0/(360D0*A**3))
-         GAMMA=GAMMA/(K*(K+1D0)*(K+2D0)*(K+3D0)*(K+4D0))
+         FTGAMMA=FTGAMMA/(K*(K+1D0)*(K+2D0)*(K+3D0)*(K+4D0))
       ENDIF
 C
       END
