@@ -7,7 +7,7 @@ C
 
       SUBROUTINE DENLOCAL(CF,KNI,N,ICOMAX,IRMAX)
       INTEGER N,ICOMAX,IRMAX
-      DOUBLE PRECISION F(N),CF(N),X(N)
+      DOUBLE PRECISION CF(N)
       INTEGER KNI(N)
 C
       INTEGER I,J,ICR,IC
